@@ -14,9 +14,11 @@ class AltiumRun:
 
     def __init__(self, altium_version: Optional[str] = None, use_internal_logger: bool = True):
         self.set_used_altium_version()
+        print("AltiumRun15-1")
         self._project_path = os.path.dirname(sys.argv[0]) + "/scripting_project_adprod"
-
+        print("AltiumRun15-2")
         pathlib.Path(self._project_path).mkdir(parents=True, exist_ok=True)
+        print("AltiumRun15-3")
         self.external_scripts_path: List[str] = []
         r"""A list of all the paths to the needed scripts."""
 
@@ -45,10 +47,12 @@ class AltiumRun:
         """
         # 获取名为AD15的系统环境变量
         altium_install = AltiumHelper.get_system_env_variable("AD15")
+        print(f"altium_install:{altium_install}")
         if altium_install is None:
             print("can not read system ad path var")
             return False
         self._altium_path = altium_install + r"\DXP.EXE"
+        print(f"self._altium_path :{self._altium_path}")
         return True
 
     def set_scripting_project_path(self, path: str) -> None:
@@ -253,35 +257,51 @@ class AltiumRun:
         # Generate the path for the scripting project
         if not os.path.exists(self._project_path):
             os.makedirs(self._project_path)
+            print("AltiumRun15:1")
         if not os.path.exists(self._project_path + "/data"):
             os.makedirs(self._project_path + "/data")
-
+            print("AltiumRun15:2")
         self._internal_scripts_path.clear()
+        print("AltiumRun15:3")
         if self._use_internal_logger:
             self._generate_logger_script()
+            print("AltiumRun15:4")
         self._generate_main_script()
+        print("AltiumRun15:5")
         self._internal_scripts_path.append(self._project_path + "/exportAdBom2BasicBom.pas")
+        print("AltiumRun15:6")
         self._generate_script_from_base_top("exportAdBom2BasicBom.pas")
+        print("AltiumRun15:7")
 
         self._internal_scripts_path.append(self._project_path + "/updateSitNum0302.pas")
+        print("AltiumRun15:8")
         self._generate_script_from_base_top("updateSitNum0302.pas")
+        print("AltiumRun15:9")
 
         self._generate_scripting_project()
+        print("AltiumRun15:10")
         self.get_log_file_path()
 
 
 
         project = (self._project_path + "/script_project.PrjScr").replace("/", "\\")
+        print("AltiumRun15:11")
         script = "main.pas>SCRIPTING_SYSTEM_MAIN"
         command = f"\"{self._altium_path}\" -RScriptingSystem:RunScript(ProjectName=\"{project}\"|ProcName=\"{script}\")"
-
+        print("AltiumRun15:12")
         f_running = open(self._project_path + "/data/running", 'w')
+        print("AltiumRun15:13")
         f_running.write("")
+        print("AltiumRun15:14")
         f_running.close()
+        print("AltiumRun15:15")
 
         self._process = subprocess.Popen(command)
+        print("AltiumRun15:16")
         if wait_until_finished:
+            print("AltiumRun15:17")
             return self.wait_until_finished(timeout)
+        print("AltiumRun15:18")
         return self.wait_until_finished(0.1)
 
     def runTop3(self, wait_until_finished: bool = True, timeout: float = 10) -> bool:
