@@ -47,6 +47,7 @@ class AltiumRun:
         if altium_install is None:
             return False
         self._altium_path = altium_install + r"\X2.exe"
+        print(f"AltiumRunEnv15.py:{self._altium_path}")
         return True
 
     def set_scripting_project_path(self, path: str) -> None:
@@ -314,33 +315,47 @@ class AltiumRun:
         # Generate the path for the scripting project
         if not os.path.exists(self._project_path):
             os.makedirs(self._project_path)
+            print("AltiumRunEnv15.py-1")
         if not os.path.exists(self._project_path + "/data"):
             os.makedirs(self._project_path + "/data")
-
+        print("AltiumRunEnv15.py-2")
         self._internal_scripts_path.clear()
+        print("AltiumRunEnv15.py-3")
         if self._use_internal_logger:
             self._generate_logger_script()
+            print("AltiumRunEnv15.py-4")
         self._generate_main_script()
+        print("AltiumRunEnv15.py-5")
         self._internal_scripts_path.append(self._project_path + "/exportAdBom2BasicBom.pas")
+        print("AltiumRunEnv15.py-6")
         self._generate_script_from_base_top("exportAdBom2BasicBom.pas")
-
+        print("AltiumRunEnv15.py-7")
         self._internal_scripts_path.append(self._project_path + "/updateSitNum0302.pas")
+        print("AltiumRunEnv15.py-8")
         self._generate_script_from_base_top("updateSitNum0302.pas")
+        print("AltiumRunEnv15.py-9")
 
         self._generate_scripting_project()
+        print("AltiumRunEnv15.py-10")
         self.get_log_file_path()
+        print("AltiumRunEnv15.py-11")
 
 
 
         project = (self._project_path + "/script_project.PrjScr").replace("/", "\\")
+        print("AltiumRunEnv15.py-12")
         script = "main.pas>SCRIPTING_SYSTEM_MAIN"
         command = f"\"{self._altium_path}\" -RScriptingSystem:RunScript(ProjectName=\"{project}\"|ProcName=\"{script}\")"
-
+        print("AltiumRunEnv15.py-13")
         f_running = open(self._project_path + "/data/running", 'w')
+        print("AltiumRunEnv15.py-14")
         f_running.write("")
+        print("AltiumRunEnv15.py-15")
         f_running.close()
+        print("AltiumRunEnv15.py-16")
 
         self._process = subprocess.Popen(command)
+        print("AltiumRunEnv15.py-17")
         if wait_until_finished:
             return self.wait_until_finished(timeout)
         return self.wait_until_finished(0.1)
